Returns the incidence matrix
for the underlying or reflexivity graph of the AS-PCD
whose vertices are the data points in Xp
in the multiple triangle case.
AS proximity regions are defined
with respect to the Delaunay triangles based on Yp points and
vertex regions are based on the center M="CC"
for circumcenter of each Delaunay triangle or \(M=(\alpha,\beta,\gamma)\)
in barycentric coordinates in the
interior of each Delaunay triangle;
default is M="CC", i.e., circumcenter of each triangle.
Loops are allowed, so the diagonal entries are all equal to 1.
Each Delaunay triangle is first converted to
an (nonscaled) basic triangle so that M will be the same
type of center for each Delaunay triangle
(this conversion is not necessary when M is \(CM\)).
Convex hull of Yp is partitioned
by the Delaunay triangles based on Yp points
(i.e., multiple triangles are the set of these Delaunay triangles
whose union constitutes the
convex hull of Yp points).
For the incidence matrix loops are allowed,
so the diagonal entries are all equal to 1.
See (ceyhan:Phd-thesis,ceyhan:stamet2016;textualpcds.ugraph)
for more on the AS-PCDs.
Also, see (okabe:2000,ceyhan:comp-geo-2010,sinclair:2016;textualpcds.ugraph)
for more on Delaunay triangulation and the corresponding algorithm.