Learn R Programming

pcds.ugraph (version 0.1.1)

inci.mat.undPEstd.tri: Incidence matrix for the underlying or reflexivity graph of Proportional Edge Proximity Catch Digraphs (PE-PCDs) - standard equilateral triangle case

Description

Returns the incidence matrix for the underlying or reflexivity graph of the PE-PCD whose vertices are the given 2D numerical data set, Xp, in the standard equilateral triangle \(T_e=T(v=1,v=2,v=3)=T((0,0),(1,0),(1/2,\sqrt{3}/2))\).

PE proximity region is constructed with respect to the standard equilateral triangle \(T_e\) with expansion parameter \(r \ge 1\) and vertex regions are based on the center \(M=(m_1,m_2)\) in Cartesian coordinates or \(M=(\alpha,\beta,\gamma)\) in barycentric coordinates in the interior of \(T_e\); default is \(M=(1,1,1)\), i.e., the center of mass of \(T_e\). Loops are allowed, so the diagonal entries are all equal to 1.

See also (ceyhan:Phd-thesis,ceyhan:comp-geo-2010,ceyhan:stamet2016;textualpcds.ugraph).

Usage

inci.mat.undPEstd.tri(
  Xp,
  r,
  M = c(1, 1, 1),
  ugraph = c("underlying", "reflexivity")
)

Value

Incidence matrix for the underlying or reflexivity graph of the PE-PCD with vertices being 2D data set, Xp

in the standard equilateral triangle where PE proximity regions are defined with M-vertex regions.

Arguments

Xp

A set of 2D points which constitute the vertices of the underlying or reflexivity graph of the PE-PCD.

r

A positive real number which serves as the expansion parameter in PE proximity region; must be \(\ge 1\).

M

A 2D point in Cartesian coordinates or a 3D point in barycentric coordinates which serves as a center in the interior of the standard equilateral triangle \(T_e\); default is \(M=(1,1,1)\) i.e. the center of mass of \(T_e\).

ugraph

The type of the graph based on PE-PCDs, "underlying" is for the underlying graph, and "reflexivity" is for the reflexivity graph (default is "underlying").

Author

Elvan Ceyhan

References

See Also

inci.mat.undPEtri, inci.mat.undPE, and inci.matPEstd.tri

Examples

Run this code
#\donttest{
A<-c(0,0); B<-c(1,0); C<-c(1/2,sqrt(3)/2);
Te<-rbind(A,B,C)
n<-10

set.seed(1)
Xp<-pcds::runif.std.tri(n)$gen.points

M<-as.numeric(pcds::runif.std.tri(1)$g)

inc.mat<-inci.mat.undPEstd.tri(Xp,r=1.25,M)
inc.mat
(sum(inc.mat)-n)/2
num.edgesPEstd.tri(Xp,r=1.25,M)$num.edges

pcds::dom.num.greedy(inc.mat)
pcds::Idom.num.up.bnd(inc.mat,2)
#}

Run the code above in your browser using DataLab